@@ -61,7 +61,7 @@ opts = [
                help='Maximum number of attempts to try to read the '
                     'partition.'),
     cfg.IntOpt('image_convert_memory_limit',
-               default=2048,
+               default=1024,
                help='Memory limit for "qemu-img convert" in MiB. Implemented '
                     'via the address space resource limit.'),
     cfg.IntOpt('image_convert_attempts',
@@ -80,8 +80,6 @@ _PARTED_PRINT_RE = re.compile(r"^(\d+):([\d\.]+)MiB:"
 CONFIGDRIVE_LABEL = "config-2"
 MAX_CONFIG_DRIVE_SIZE_MB = 64
 
-GPT_SIZE_SECTORS = 33
-
 # Maximum disk size supported by MBR is 2TB (2 * 1024 * 1024 MB)
 MAX_DISK_SIZE_MB_SUPPORTED_BY_MBR = 2097152
 
@@ -409,23 +407,10 @@ def _retry_on_res_temp_unavailable(exc):
 def convert_image(source, dest, out_format, run_as_root=False):
     """Convert image to other format."""
     cmd = ('qemu-img', 'convert', '-O', out_format, source, dest)
-    # NOTE(TheJulia): Staticly set the MALLOC_ARENA_MAX to prevent leaking
-    # and the creation of new malloc arenas which will consume the system
-    # memory. If limited to 1, qemu-img consumes ~250 MB of RAM, but when
-    # another thread tries to access a locked section of memory in use with
-    # another thread, then by default a new malloc arena is created,
-    # which essentially balloons the memory requirement of the machine.
-    # Default for qemu-img is 8 * nCPU * ~250MB (based on defaults +
-    # thread/code/process/library overhead. In other words, 64 GB. Limiting
-    # this to 3 keeps the memory utilization in happy cases below the overall
-    # threshold which is in place in case a malicious image is attempted to
-    # be passed through qemu-img.
-    env_vars = {'MALLOC_ARENA_MAX': '3'}
     try:
         utils.execute(*cmd, run_as_root=run_as_root,
                       prlimit=_qemu_img_limits(),
-                      use_standard_locale=True,
-                      env_variables=env_vars)
+                      use_standard_locale=True)
     except processutils.ProcessExecutionError as e:
         if ('Resource temporarily unavailable' in e.stderr
             or 'Cannot allocate memory' in e.stderr):
@@ -512,24 +497,13 @@ def destroy_disk_metadata(dev, node_uuid):
     # erasing partition data.
     # This is the same bug as
     # https://bugs.launchpad.net/ironic-python-agent/+bug/1737556
-
-    # Overwrite the Primary GPT, catch very small partitions (like EBRs)
     dd_device = 'of=%s' % dev
-    dd_count = 'count=%s' % GPT_SIZE_SECTORS
-    dev_size = get_dev_block_size(dev)
-    if dev_size < GPT_SIZE_SECTORS:
-        dd_count = 'count=%s' % dev_size
-    utils.execute('dd', 'bs=512', 'if=/dev/zero', dd_device, dd_count,
+    gpt_backup = get_dev_block_size(dev) - 33
+    dd_seek = 'seek=%i' % gpt_backup
+    utils.execute('dd', 'bs=512', 'if=/dev/zero', dd_device, 'count=33',
                   run_as_root=True, use_standard_locale=True)
-
-    # Overwrite the Secondary GPT, do this only if there could be one
-    if dev_size > GPT_SIZE_SECTORS:
-        gpt_backup = dev_size - GPT_SIZE_SECTORS
-        dd_seek = 'seek=%i' % gpt_backup
-        dd_count = 'count=%s' % GPT_SIZE_SECTORS
-        utils.execute('dd', 'bs=512', 'if=/dev/zero', dd_device, dd_count,
-                      dd_seek, run_as_root=True, use_standard_locale=True)
-
+    utils.execute('dd', 'bs=512', 'if=/dev/zero', dd_device, 'count=33',
+                  dd_seek, run_as_root=True, use_standard_locale=True)
     # Go ahead and let sgdisk run as well.
     utils.execute('sgdisk', '-Z', dev, run_as_root=True,
                   use_standard_locale=True)
@@ -574,11 +548,9 @@ def _get_configdrive(configdrive, node_uuid, tempdir=None):
 
     try:
         data = io.BytesIO(base64.decode_as_bytes(data))
-    except Exception as exc:
-        error_msg = (_('Config drive for node %(node)s is not base64 encoded '
-                       'or the content is malformed. %(cls)s: %(err)s.')
-                     % {'node': node_uuid, 'err': exc,
-                        'cls': type(exc).__name__})
+    except TypeError:
+        error_msg = (_('Config drive for node %s is not base64 encoded '
+                       'or the content is malformed.') % node_uuid)
         if is_url:
             error_msg += _(' Downloaded from "%s".') % configdrive
         raise exception.InstanceDeployFailure(error_msg)
